//
//  ViewController.swift
//  TestSciChart
//
//  Created by Vlad Badea on 8/27/23.
//

import Cocoa
import SciChart

class ViewController: NSViewController {
    
    private let chartSurface = SCIChartSurface()

    override func viewDidLoad() {
        super.viewDidLoad()

        chartSurface.translatesAutoresizingMaskIntoConstraints = false
        view.addSubview(chartSurface)
        
        NSLayoutConstraint.activate([
            chartSurface.topAnchor.constraint(equalTo: view.topAnchor),
            chartSurface.leadingAnchor.constraint(equalTo: view.leadingAnchor),
            chartSurface.trailingAnchor.constraint(equalTo: view.trailingAnchor),
            chartSurface.bottomAnchor.constraint(equalTo: view.bottomAnchor)
        ])
        
        let xAxis = SCINumericAxis()
        let yAxis = SCINumericAxis()

        xAxis.visibleRangeChangeListener = { axis, oldRange, newRange, _ in
            print("visibleRangeChangeListener triggered - oldRange is \(oldRange)    newRange is \(newRange)")
            if newRange.minAsDouble < -10 {
                axis.visibleRange = oldRange
            }
        }
        
        let dataSeries = SCIXyDataSeries(xType: .double, yType: .double)
        let count = 100
        let xValues = SCIDoubleValues(capacity: count)
        let yValues = SCIDoubleValues(capacity: count)
        for i in 0 ..< count {
            xValues.add(Double(i))
            yValues.add(Double.random(in: 0..<50))
        }
        dataSeries.append(x: xValues, y: yValues)
        
        let rSeries = SCIFastLineRenderableSeries()
        rSeries.dataSeries = dataSeries
        
        SCIUpdateSuspender.usingWith(chartSurface) {
            self.chartSurface.xAxes.add(xAxis)
            self.chartSurface.yAxes.add(yAxis)
            self.chartSurface.renderableSeries.add(rSeries)
            self.chartSurface.chartModifiers.add(items: SCIZoomPanModifier())
        }
    }
}
